@@ -8,7 +8,7 @@ bd.densdep.optim<-function(x,minK=0,maxK=0,discrete=TRUE,continuous=FALSE,lambda
 	resdiscrete<-bd.densdep.optim.discrete(x,maxK,minK)}
 	if (continuous==TRUE){
 		if (Kinit==0) {Kinit<-(length(x)+2)}
-	rescont<-subplex(c(lambdainit,muinit,Kinit),LikComp2,model=-1,x=x,minN=minK,control=list(reltol=10^(-10)))}
+	rescont<-subplex(c(lambdainit,muinit,Kinit),LikComp2,root=1,model=-1,x=x,minN=minK,control=list(reltol=10^(-10)))}
 res<-list(resdiscrete,rescont)
 res
 }
